@@ -1,5 +1,5 @@
 from django.views.generic import FormView
-from django.contrib.auth.forms import AuthenticationForm, UserCreationForm, UserChangeForm
+from django.contrib.auth.forms import AuthenticationForm, UserCreationForm, UserChangeForm, PasswordChangeForm
 from django.http import HttpResponseRedirect
 from django.core.urlresolvers import reverse
 from django.contrib.auth import login as auth_login, authenticate
@@ -9,22 +9,31 @@ from django.forms import HiddenInput
 
 from user.forms import ProfileForm
 
-class SignInView(FormView):
+class FormMixin():
+    def construct_widgets(self, fields, placeholders):
+        for field in fields.keys():
+            if field in placeholders.keys():
+                fields[field].widget.attrs = {
+                    'class': 'form-control',
+                    'placeholder': placeholders[field]
+                }
+            else:
+                del fields[field]
+    
+class SignInView(FormView, FormMixin):
     form_class = AuthenticationForm
     success_url = '/'
     
     def get_form(self, *args):
         form = super(SignInView, self).get_form(self.get_form_class())
         fields = form.fields
-        fields['username'].widget.attrs = {
-            'class': 'form-control',
-            'placeholder': 'Username'
+        
+        placeholders = {
+            'username': 'Username',
+            'password': 'Password',
         }
         
-        fields['password'].widget.attrs = {
-            'class': 'form-control',
-            'placeholder': 'Password'
-        }
+        self.construct_widgets(fields, placeholders)
         
         return form
         
@@ -38,27 +47,21 @@ class SignInView(FormView):
         return HttpResponseRedirect(self.request.POST.get('next') or self.request.GET.get('next') or reverse('profile'))
         
         
-class SignUpView(FormView):
+class SignUpView(FormView, FormMixin):
     form_class = UserCreationForm
     success_url = '/'
     
     def get_form(self, *args):
         form = super(SignUpView, self).get_form(self.get_form_class())
         fields = form.fields
-        fields['username'].widget.attrs = {
-            'class': 'form-control',
-            'placeholder': 'Username'
+        
+        placeholders = {
+            'username': 'Username',
+            'password1': 'Password',
+            'password2': 'Confirm Password',
         }
         
-        fields['password1'].widget.attrs = {
-            'class': 'form-control',
-            'placeholder': 'Password'
-        }
-        
-        fields['password2'].widget.attrs = {
-            'class': 'form-control',
-            'placeholder': 'Confirm Password'
-        }
+        self.construct_widgets(fields, placeholders)
         
         return form
         
@@ -78,7 +81,7 @@ class SignUpView(FormView):
         return response
  
  
-class ProfileView(FormView):
+class ProfileView(FormView, FormMixin):
     form_class = ProfileForm
     success_url = '/'
     
@@ -103,25 +106,11 @@ class ProfileView(FormView):
         
         form.initial = initial
         
-        for field in fields.keys():
-            if field in placeholders.keys():
-                fields[field].widget.attrs = {
-                    'class': 'form-control',
-                    'placeholder': placeholders[field]
-                }
-            else:
-                del fields[field]
+        self.construct_widgets(fields, placeholders)
         
         return form
     
     
-    def form_invalid(self, form):
-        print 'invalid'
-        print form._errors
-        response = super(ProfileView, self).form_invalid(form)
-        return response
-        
-    
     def form_valid(self, form):
         response = super(ProfileView, self).form_valid(form)
         
@@ -130,4 +119,32 @@ class ProfileView(FormView):
         messages.add_message(self.request, messages.SUCCESS, 'Profile Change was successful!')
         
         return response
-        
\ No newline at end of file
+
+class PasswordChangeView(FormView, FormMixin):
+    form_class = PasswordChangeForm
+    success_url = '/'
+    
+    def get_form(self, *args):
+        self.success_url = reverse('profile')
+        form = self.get_form_class()(self.request.user, self.request.POST if self.request.POST else None)
+        fields = form.fields
+        user = self.request.user
+        
+        placeholders = {
+            'old_password': 'Old Password',
+            'new_password1': 'New Password',
+            'new_password2': 'Confirm New Password'
+        }
+        
+        self.construct_widgets(fields, placeholders)
+        
+        return form
+    
+    def form_valid(self, form):
+        response = super(PasswordChangeView, self).form_valid(form)
+        
+        form.save()
+        
+        messages.add_message(self.request, messages.SUCCESS, 'Password Change was successful!')
+        
+        return response
\ No newline at end of file
